@@ -66,7 +66,7 @@ class OnepV1():
     def __init__(self,
                  host='m2.exosite.com',
                  port='80',
-                 url='/api:v1/rpc/process',
+                 url='/onep:v1/rpc/process',
                  https=False,
                  httptimeout=10,
                  agent=None,
@@ -200,9 +200,11 @@ class OnepV1():
         if self.deferred.has_requests(cik):
             calls = self._composeCalls(
                 self.deferred.get_method_args_pairs(cik))
-            r = self._callJsonRPC(cik, calls, returnreq=True)
-            # remove deferred calls
-            self.deferred.reset(cik)
+            try:
+                r = self._callJsonRPC(cik, calls, returnreq=True)
+            finally:
+                # remove deferred calls
+                self.deferred.reset(cik)
             return r
         raise JsonRPCRequestException('No deferred requests to send.')
 
